import { useState } from 'react';
import BarcodeScannerComponent from 'react-qr-barcode-scanner';
import toast, { Toaster } from 'react-hot-toast';
import { Container, Row, Col } from 'react-bootstrap';

// Styles
import './App.css';
import 'bootstrap/dist/css/bootstrap.min.css';

function App() {
  // State to store the latest scanned data
  const [currentData, setCurrentData] = useState('No result');

  // State to store an array of scanned results for history tracking
  const [scanHistory, setScanHistory] = useState([]);

  /**
   * Handles the scanning result.
   * @param {Error} err - Error, if any, from the scanner.
   * @param {Object} result - The scanning result object.
   */
  const handleScan = (err, result) => {
    if (result) {
      // Update current data and add it to the scan history
      setCurrentData(result.text);
      setScanHistory(prevHistory => [...prevHistory, result.text]);

      // Show a success notification using toast
      toast.success(`Product scanned: ${result.text}`);
    } else {
      setCurrentData('No result'); // Set message if no result
    }
  };

    return (
	<Container>
	    <Row>
		<Col>
	    {/* Notification toaster for displaying scan success messages */}
		    <Toaster position="top-right" reverseOrder={false} />
		</Col>
	    </Row>
	    <Row>
		<Col>

	    {/* Scanner title */}
		    <div className="title">BrmInv</div>
		</Col>
	    </Row>

	    <Row>
		<Col>

	    {/* Barcode scanner component */}
	    <div className="scan" style={{border: '1px solid black'}}>
		<BarcodeScannerComponent
		    width={"100%"}
		    height={"auto"}
		    onUpdate={handleScan}
		    delay={1500} // 1.5 seconds delay between scans
		/>
	    </div>
		</Col>
	    </Row>

	    <Row>
		<Col>
	    {/* Display the current scanned data */}
		    <p>Scanned Data: {currentData}</p>
		</Col>
	    </Row>

	    <Row>
		<Col>
	    {/* Table to display scan history */}
	    <h2>Scan History</h2>
	    <table>
		<thead>
		    <tr>
			<th>#</th>
			<th>Scanned Result</th>
		    </tr>
		</thead>
		<tbody>
		    {scanHistory.map((result, index) => (
			<tr key={index}>
			    <td>{index + 1}</td>
			    <td>{result}</td>
			</tr>
		    ))}
		</tbody>
	    </table>
		</Col>
	    </Row>
	    </Container>
		);
    }

    export default App;
